@@ -3,7 +3,8 @@ import fmdt
 import sys
 
 # Directory whose videos you would like to view
-directory = "/run/media/ejovo/Seagate Portable Drive/Meteors/Watec12mm/Meteor/"
+# directory = "/run/media/ejovo/Seagate Portable Drive/Meteors/Watec12mm/Meteor/"
+directory = "/home/ejovo/Videos/Watec12mm"
 
 def print_help() -> None:
     print("Type the name of the directory you wish to process:")
@@ -17,7 +18,7 @@ elif directory is None:
     directory = sys.argv[1]
 
 args = {
-    "out_track_file": "tracks.txt",
+    "trk_out_path": "tracks.txt",
     "light_min": 190,
     "light_max": 235, # None of the videos fail with _just_ a light max
     "trk_all": True,
@@ -26,4 +27,11 @@ args = {
 
 a = fmdt.Args(detect_args=args)
 
+# List the files in the directory
+
+print(os.listdir(directory))
+
+print("Running fmdt.detect_directory with args:")
+print(a.detect_args)
+
 fmdt.detect_directory(directory, a, True)
\ No newline at end of file
